<?php

namespace Drupal\term_glossary\Form;

use Drupal\Core\Entity\EntityFieldManagerInterface;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Config\ConfigFactoryInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;

/**
 * Class TermGlossaryConfigForm.
 */
class TermGlossaryConfigForm extends ConfigFormBase {

  /**
   * Drupal\Core\Entity\EntityTypeManagerInterface definition.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected EntityTypeManagerInterface $entityTypeManager;

  /**
   * @var \Drupal\Core\Entity\EntityFieldManagerInterface
   */
  protected EntityFieldManagerInterface $entityFieldManager;

  /**
   * Constructs a new GlossaryConfigForm object.
   */
  public function __construct(
    ConfigFactoryInterface $config_factory,
    EntityTypeManagerInterface $entity_type_manager,
    EntityFieldManagerInterface $entityFieldManager
  ) {
    parent::__construct($config_factory);
    $this->entityTypeManager = $entity_type_manager;
    $this->entityFieldManager = $entityFieldManager;
    $this->configFactory = $config_factory;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('config.factory'),
      $container->get('entity_type.manager'),
      $container->get('entity_field.manager')
    );
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'glossary.glossaryconfig',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'glossary_config_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('term_glossary.glossaryconfig');

    $vocab_types = $this->entityTypeManager->getStorage('taxonomy_vocabulary')
      ->loadMultiple();
    $vocab_options = [];
    foreach ($vocab_types as $key => $vocab) {
      $vocab_options[$key] = $vocab->get('name');
    }

    $form['vocab'] = [
      '#type' => 'select',
      '#title' => $this->t('which vocabulary to use for glossary'),
      '#options' => $vocab_options,
      '#default_value' => $config->get('vocab') ?: [],
      '#required' => TRUE,
    ];

    $form['integration_type'] = [
      '#type' => 'radios',
      '#title' => 'Select integration type',
      '#default_value' => $config->get('integration_type') ?: '',
      '#options' => [
        'custom_js' => $this->t('CUSTOM JS/CSS: span class (glos-term) and Add "data-gterm=" which is the term id'),
        'default' => $this->t('Jquery ui dialog with the term name and description, minimal styles for highlighted terms'),
      ],
      '#description' => $this->t('This sets what will happen when a glossary term is found in content. <br/> If you select "CUSTOM JS" it\'s up to you to handle the javascript and css side of what happens when someone clicks a term'),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    parent::submitForm($form, $form_state);

    $this->configFactory->getEditable('term_glossary.glossaryconfig')
      ->set('vocab', $form_state->getValue('vocab'))
      ->set('integration_type', $form_state->getValue('integration_type'))
      ->save();
  }

}
